git

package
v0.1.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 5, 2026 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetLatestTag

func GetLatestTag(path string) (tag, commit string, err error)

func GetRemotes

func GetRemotes(path string) (map[string]string, error)

TODO(puerco): Port this to pure go before making it public

func RepoVCSLocator

func RepoVCSLocator(path string) (string, error)

func RepoVersion

func RepoVersion(path string) (tag, commit string, err error)

RepoVersion

Types

type HeadDetails

type HeadDetails struct {
	CommitSHA string
	Tag       string
}

func GetHeadDetails

func GetHeadDetails(path string) (*HeadDetails, error)

TODO(puerco): Port this to pure go before making it public

Jump to