Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetLatestTag ¶
func GetRemotes ¶
TODO(puerco): Port this to pure go before making it public
func RepoVCSLocator ¶
Types ¶
type HeadDetails ¶
func GetHeadDetails ¶
func GetHeadDetails(path string) (*HeadDetails, error)
TODO(puerco): Port this to pure go before making it public
Click to show internal directories.
Click to hide internal directories.